Rename signed fields to signed portion
diff --git a/ndn-cpp/c/encoding/binary-xml-data.h b/ndn-cpp/c/encoding/binary-xml-data.h
index 3168cb1..caf9e35 100644
--- a/ndn-cpp/c/encoding/binary-xml-data.h
+++ b/ndn-cpp/c/encoding/binary-xml-data.h
@@ -19,28 +19,28 @@
 /**
  * Encode the data packet as binary XML.
  * @param data Pointer to the data object to encode.
  * @param signedFieldsBeginOffset Return the offset in the encoding of the beginning of the fields which are signed.
  * If you are not encoding in order to sign, you can ignore this returned value.
  * @param signedFieldsEndOffset Return the offset in the encoding of the end of the fields which are signed.
  * If you are not encoding in order to sign, you can ignore this returned value.
  * @param encoder Pointer to the ndn_BinaryXmlEncoder struct which receives the encoding. 
  * @return 0 for success, else an error code.
  */
 ndn_Error ndn_encodeBinaryXmlData
-  (struct ndn_Data *data, unsigned int *signedFieldsBeginOffset, unsigned int *signedFieldsEndOffset, struct ndn_BinaryXmlEncoder *encoder);
+  (struct ndn_Data *data, unsigned int *signedPortionBeginOffset, unsigned int *signedPortionEndOffset, struct ndn_BinaryXmlEncoder *encoder);
 
 /**
  * Decode the data packet as binary XML and set the fields in the data object.
  * @param data Pointer to the data object whose fields are updated.
  * @param signedFieldsBeginOffset Return the offset in the input buffer of the beginning of the fields which are signed.
  * If you are not decoding in order to verify, you can ignore this returned value.
  * @param signedFieldsEndOffset Return the offset in the input buffer of the end of the fields which are signed.
  * If you are not decoding in order to verify, you can ignore this returned value.
  * @param decoder Pointer to the ndn_BinaryXmlDecoder struct which has been initialized with the buffer to decode. 
  * @return 0 for success, else an error code.
  */
 ndn_Error ndn_decodeBinaryXmlData
-  (struct ndn_Data *data, unsigned int *signedFieldsBeginOffset, unsigned int *signedFieldsEndOffset, struct ndn_BinaryXmlDecoder *decoder);
+  (struct ndn_Data *data, unsigned int *signedPortionBeginOffset, unsigned int *signedPortionEndOffset, struct ndn_BinaryXmlDecoder *decoder);
 
 #ifdef __cplusplus
 }
@@ -19,28 +19,28 @@
  * Encode the data packet as binary XML.
  * @param data Pointer to the data object to encode.
- * @param signedFieldsBeginOffset Return the offset in the encoding of the beginning of the fields which are signed.
+ * @param signedPortionBeginOffset Return the offset in the encoding of the beginning of the signed portion.
  * If you are not encoding in order to sign, you can ignore this returned value.
@@ -19,28 +19,28 @@
  * If you are not encoding in order to sign, you can ignore this returned value.
- * @param signedFieldsEndOffset Return the offset in the encoding of the end of the fields which are signed.
+ * @param signedPortionEndOffset Return the offset in the encoding of the end of the signed portion.
  * If you are not encoding in order to sign, you can ignore this returned value.
  * @param encoder Pointer to the ndn_BinaryXmlEncoder struct which receives the encoding. 
@@ -19,28 +19,28 @@
  * Decode the data packet as binary XML and set the fields in the data object.
  * @param data Pointer to the data object whose fields are updated.
- * @param signedFieldsBeginOffset Return the offset in the input buffer of the beginning of the fields which are signed.
+ * @param signedPortionBeginOffset Return the offset in the input buffer of the beginning of the signed portion.
  * If you are not decoding in order to verify, you can ignore this returned value.
@@ -19,28 +19,28 @@
  * If you are not decoding in order to verify, you can ignore this returned value.
- * @param signedFieldsEndOffset Return the offset in the input buffer of the end of the fields which are signed.
+ * @param signedPortionEndOffset Return the offset in the input buffer of the end of the signed portion.
  * If you are not decoding in order to verify, you can ignore this returned value.
  * @param decoder Pointer to the ndn_BinaryXmlDecoder struct which has been initialized with the buffer to decode. 